@@ -1407,7 +1407,7 @@ public class MenuBar {
 	}
 
 	/**
-	 * toggle enabling additional export menu items in dependency of device data capability
+	 * toggle enabling GPS related export menu items in dependency of device data capability
 	 */
 	public void updateAdditionalGPSMenuItems() {
 		final boolean isGPSData = this.application.getActiveDevice().isActualRecordSetWithGpsData();
@@ -1440,6 +1440,24 @@ public class MenuBar {
 		}
 	}
 
+	/**
+	 * toggle enabling GPS related menu items in dependency of device data capability
+	 */
+	public void updateDevicePropertyEditorItem() {
+		final boolean isEnabled = this.application.getActiveDevice().getDeviceConfiguration().isEditable();
+		if (Thread.currentThread().getId() == this.application.getThreadId()) {
+			this.devicePropertyFileEditMenuItem.setEnabled(isEnabled);
+		}
+		else {
+			GDE.display.asyncExec(new Runnable() {
+				@Override
+				public void run() {
+					MenuBar.this.devicePropertyFileEditMenuItem.setEnabled(isEnabled);
+				}
+			});
+		}
+	}
+
 	private void openPreferencesDialog(SelectionEvent evt) {
 		if (log.isLoggable(Level.FINEST)) log.log(Level.FINEST, "preferencesFileMenuItem.widgetSelected, event=" + evt); //$NON-NLS-1$
 		// check if other none modal dialog is open
